/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2015 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.7                   *
*********************************************************************************
* Id: fxmmKeyDialog.cpp,                          2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>
#include "config.h"
#include "icons.h"
#include "fxmmKeyDialog.h"

// Map
FXDEFMAP(fxmmKeyDialog) fxmmKeyDialogMap[]={
  FXMAPFUNC(SEL_COMMAND,  fxmmKeyDialog::ID_CANCEL,     fxmmKeyDialog::onCmdCancel),
  FXMAPFUNC(SEL_COMMAND,  fxmmKeyDialog::ID_ACCEPT,     fxmmKeyDialog::onCmdAccept),
  FXMAPFUNC(SEL_COMMAND,  fxmmKeyDialog::ID_FILE,       fxmmKeyDialog::onCmdFile),
  };

// Object implementation
FXIMPLEMENT(fxmmKeyDialog,FXDialogBox,fxmmKeyDialogMap,ARRAYNUMBER(fxmmKeyDialogMap))


// Create dialog
fxmmKeyDialog::fxmmKeyDialog(FXWindow *own)
  :FXDialogBox(own,"Set the KEY",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 4,4,4,4, 4,4){
  cancelicon=new FXGIFIcon(getApp(),m_cancel);
  accepticon=new FXGIFIcon(getApp(),m_accept);

  dialogframe=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);
  new FXLabel(dialogframe,tr("Press the button  [ ACCEPT ]  to set your KEY"),NULL,ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);

  // input field
  inputframe=new FXHorizontalFrame(dialogframe,LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 3,3,3,3, 0,0);
  pw_input=new FXTextField(inputframe,60,NULL,0,TEXTFIELD_PASSWD|TEXTFIELD_ENTER_ONLY|JUSTIFY_LEFT,0,0,0,0, 3,3,3,3);

  // buttons
  buttonframe=new FXHorizontalFrame(dialogframe,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|PACK_UNIFORM_WIDTH,0,0,0,0, 3,3,3,3, 10,10);
  new FXButton(buttonframe,tr("&ACCEPT"),accepticon,this,ID_ACCEPT,BUTTON_NORMAL,0,0,0,0,10,10);
  new FXButton(buttonframe,tr("&EXIT"),cancelicon,this,ID_CANCEL,BUTTON_DEFAULT|BUTTON_NORMAL,0,0,0,0,10,10);
  new FXButton(buttonframe,tr("&FILE"),NULL,this,ID_FILE,BUTTON_DEFAULT|BUTTON_NORMAL,0,0,0,0,10,10);
  new FXButton(buttonframe,tr("&PASTE"),NULL,pw_input,FXTextField::ID_PASTE_SEL,BUTTON_DEFAULT|BUTTON_NORMAL,0,0,0,0,10,10);
  new FXButton(buttonframe,tr("&DELETE"),NULL,pw_input,FXTextField::ID_DELETE_ALL,BUTTON_DEFAULT|BUTTON_NORMAL,0,0,0,0,10,10);

  // copyright
  new FXSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *copyright=new FXHorizontalFrame(dialogframe,LAYOUT_BOTTOM|LAYOUT_CENTER_X,0,0,0,0,5,5,5,5);
  FXLabel *label = new FXLabel(copyright,"FXMovieManager - Password Setting",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
  // set the same look of separators
  label->disable();

  }


// Destroy
fxmmKeyDialog::~fxmmKeyDialog(){
  delete cancelicon;
  delete accepticon;
  }

// We have to do this so as to force the initial text to be seleced
FXuint fxmmKeyDialog::execute(FXuint placement){
  create();
  pw_input->setFocus();
  pw_input->selectAll();
  show(placement);
  return getApp()->runModalFor(this);
  }

// set the key
long fxmmKeyDialog::onCmdAccept(FXObject* sender,FXSelector sel,void* ptr){
  pw_input->setFocus();
  pw_input->selectAll();
  if(!pw_input->isEditable())
    pw_input->setText("");

  FXDialogBox::onCmdAccept(sender,sel,ptr);
  return 1;
  }

// close the dialog
long fxmmKeyDialog::onCmdCancel(FXObject* sender,FXSelector sel,void* ptr){
  FXDialogBox::onCmdCancel(sender,sel,ptr);
  return 1;
  }

// get the search option
long fxmmKeyDialog::onCmdFile(FXObject* sender,FXSelector sel,void* ptr){
  FXString file = "";
  if(!fileKey())
     FXMessageBox::warning(this,MBOX_OK,"Rejecting Open File","File not Set");

  return 1;
  }


FXbool fxmmKeyDialog::fileKey(){

  const FXchar patterns[]=
      "All Files (*)"
      "\nText Files (*.txt)"
      "\nConfig Files (*.conf)";

  FXString file_k;
  FXFileDialog open(this,"Read a File");
  open.setSelectMode(SELECTFILE_EXISTING);
  open.setPatternList(patterns);
  open.setDirectory(FXPath::directory(file_k));
  if(open.execute()){
     file_k=open.getFilename();
  } else {
     return false;
  }

  FXchar chi;
  FXString chiave;
  // the key file stream
  FXFileStream stream_k;
  // open the file stream for reading
  if(stream_k.open(file_k, FXStreamLoad)){
	// read data from the file stream: local variables
	while(!stream_k.eof()){
       stream_k >> chi;
       FXStreamStatus sta=stream_k.status();
       if(sta!=FXStreamEnd){
          // strip carriages
          if(chi!='\n' && chi!='\t' && chi!='\r' && chi!=' ')
             chiave.append(chi);
       }
    }
	// close the file stream
	stream_k.close();
  }
  pw_input->setText(chiave);
  return true;
}
